@@ -3,6 +3,7 @@ import json
 from typing import List
 from functools import reduce
 from datetime import datetime
+import numpy as np
 from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.tools import list_average, safe_parse_date, list_sum
 
@@ -11,7 +12,7 @@ def _next_error(values: list): return next((x for x in values if x is not True),
 
 
 def _filter_list_errors(values: list, return_single=True):
-    values = list(filter(lambda x: x is not True, values))
+    values = list(filter(lambda x: x is not True and x != np.bool(True), values))
     return True if return_single and len(values) == 0 else (values[0] if return_single and len(values) == 1 else values)
 
 
@@ -114,7 +115,7 @@ def _same_properties(value: dict, props: List[str]):
 def _value_average(node: dict, default=0, key='value'):
     try:
         value = node.get(key)
-        return list_average(value, default) if isinstance(value, list) else value
+        return list_average(value, default) if isinstance(value, list) else (value or default)
     except Exception:
         return default
 
