@@ -9,14 +9,16 @@ from .cycle import validate_cycle
 from .impact_assessment import validate_impact_assessment
 from .organisation import validate_organisation
 from .site import validate_site
+from .source import validate_source
 
 # disable validation based on `@type`
-VALIDATE_EXISTING_NODES = os.environ.get('VALIDATE_EXISTING_NODES', 'false') == 'true'
+VALIDATE_EXISTING_NODES = os.getenv('VALIDATE_EXISTING_NODES', 'false') == 'true'
 VALIDATE_TYPE = {
     SchemaType.CYCLE.value: lambda n, nodes: validate_cycle(n, nodes),
     SchemaType.IMPACTASSESSMENT.value: lambda n, nodes: validate_impact_assessment(n, nodes),
     SchemaType.ORGANISATION.value: lambda n, nodes: validate_organisation(n, nodes),
-    SchemaType.SITE.value: lambda n, nodes: validate_site(n, nodes)
+    SchemaType.SITE.value: lambda n, nodes: validate_site(n, nodes),
+    SchemaType.SOURCE.value: lambda n, nodes: validate_source(n, nodes)
 }
 SKIP_VALIDATE_DUPLICATES = [
     SchemaType.ACTOR.value,
@@ -67,11 +69,15 @@ def validate_node(node_by_type: dict = {}, node_by_hash: dict = {}):
         List
             The list of errors/warnings for the node, which can be empty if no errors/warnings detected.
         """
-        ntype = node.get(
-            'type', node.get('@type') if VALIDATE_EXISTING_NODES else None
-        ) if isinstance(node, dict) else None
-        return [] if ntype is None else list(filter(lambda v: v is not True, flatten(
-            _validate_node_type(node_by_type, node_by_hash, ntype, node) +
-            _validate_node_children(node_by_type, node_by_hash, node)
-        )))
+        try:
+            ntype = node.get(
+                'type', node.get('@type') if VALIDATE_EXISTING_NODES else None
+            ) if isinstance(node, dict) else None
+            return [] if ntype is None else list(filter(lambda v: v is not True, flatten(
+                _validate_node_type(node_by_type, node_by_hash, ntype, node) +
+                _validate_node_children(node_by_type, node_by_hash, node)
+            )))
+        except Exception as e:
+            logger.error(f"Error validating {ntype} with id '{node.get('id', node.get('@id'))}': {str(e)}")
+            raise e
     return validate
