@@ -16,11 +16,11 @@ from .emission import validate_linked_terms
 from .input import validate_must_include_id, validate_input_country, validate_related_impacts
 from .practice import (
     validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement, validate_no_tillage,
-    validate_tillage_site_type, validate_tillage_values, validate_liveAnimal_system
+    validate_tillage_site_type, validate_tillage_values, validate_liveAnimal_system, validate_pastureGrass_key_units
 )
 from .product import (
     validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta,
-    validate_primary as validate_product_primary, validate_product_ha_functional_unit_ha
+    validate_primary as validate_product_primary, validate_product_ha_functional_unit_ha, validate_product_yield
 )
 from .completeness import validate_completeness
 from .transformation import (
@@ -245,7 +245,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
             validate_crop_residue_completeness(cycle, site) if 'completeness' in cycle and site else True,
             validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG),
             validate_excreta(cycle, 'products'),
-            validate_product_ha_functional_unit_ha(cycle, 'products')
+            validate_product_ha_functional_unit_ha(cycle, 'products'),
+            validate_product_yield(cycle, site, 'products') if site else True
         ] if len(cycle.get('products', [])) > 0 else []) +
         ([
             validate_list_dates(cycle, 'practices'),
@@ -263,7 +264,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
             validate_no_tillage(cycle.get('practices')),
             validate_tillage_site_type(cycle.get('practices'), site) if site else True,
             validate_tillage_values(cycle.get('practices')),
-            validate_liveAnimal_system(cycle)
+            validate_liveAnimal_system(cycle),
+            validate_pastureGrass_key_units(cycle)
         ] if len(cycle.get('practices', [])) > 0 else []) +
         ([
             validate_list_dates(cycle, 'transformations'),
