@@ -1,20 +1,14 @@
-from hestia_earth.schema import SchemaType, TermTermType
-from hestia_earth.utils.api import find_node
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import flatten
 
 from hestia_earth.validation.utils import _filter_list_errors
+from hestia_earth.validation.terms import get_methodModels
 
 IGNORE_MODELS = [
     'aggregatedModels'  # used only for aggregations, should not be shown as possible values
 ]
 
 
-def _methodModels():
-    terms = find_node(SchemaType.TERM, {'termType': TermTermType.MODEL.value}, limit=1000)
-    return [term.get('@id') for term in terms if term.get('@id')]
-
-
 def _allowed_characterisedIndicator_model(lookup, models: list, term_id: str):
     return [
         m for m in models if m != 'termid' and
@@ -31,7 +25,7 @@ def _is_method_allowed(lookup, term_id: str, model: str):
 
 def validate_characterisedIndicator_model(node: dict, list_key: str):
     lookup = download_lookup('characterisedIndicator-model-mapping.csv', keep_in_memory=False)
-    models = _methodModels()
+    models = get_methodModels()
 
     def validate(values: tuple):
         index, value = values
