@@ -116,11 +116,33 @@ def validate_tillage_values(practices: list):
     )
 
 
-def validate_liveAnimal_system(cycle: dict):
-    has_liveAnimal = len(filter_list_term_type(cycle.get('products', []), TermTermType.LIVEANIMAL)) > 0
-    has_system = len(filter_list_term_type(cycle.get('practices', []), TermTermType.SYSTEM)) > 0
+def validate_liveAnimal_system(data: dict):
+    has_liveAnimal = len(filter_list_term_type(data.get('products', []), TermTermType.LIVEANIMAL)) > 0
+    has_system = len(filter_list_term_type(data.get('practices', []), TermTermType.SYSTEM)) > 0
     return not has_liveAnimal or has_system or {
         'level': 'warning',
         'dataPath': '.practices',
         'message': 'should add an animal production system'
     }
+
+
+def validate_pastureGrass_key_units(data: dict, list_key: str = 'practices'):
+    validate_term_id = 'pastureGrass'
+    validate_key_units = 'ha'
+
+    def validate(values: tuple):
+        index, practice = values
+        term_id = practice.get('term', {}).get('@id')
+        key_units = practice.get('key', {}).get('units')
+        return term_id != validate_term_id or not key_units or key_units == validate_key_units or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].key",
+            'message': f"{validate_term_id} key units must be 'ha'",
+            'params': {
+                'value': key_units,
+                'expected': validate_key_units,
+                'term': practice.get('key', {})
+            }
+        }
+
+    return _filter_list_errors(flatten(map(validate, enumerate(data.get(list_key, [])))))
