@@ -1,8 +1,12 @@
+import numpy as np
 from hestia_earth.schema import TermTermType, CycleFunctionalUnit
 from hestia_earth.utils.model import find_primary_product
 from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 from hestia_earth.utils.tools import list_sum, flatten, non_empty_list
+from hestia_earth.distribution.posterior_yield import get_post
+from hestia_earth.distribution.prior_yield import get_prior
 
+from hestia_earth.validation.log import logger
 from hestia_earth.validation.utils import _list_sum, _filter_list_errors
 
 
@@ -133,7 +137,6 @@ def validate_product_ha_functional_unit_ha(cycle: dict, list_key: str = 'product
         index, product = values
         term_units = product.get('term', {}).get('units')
         value = list_sum(product.get('value', [0]))
-        print(term_units, value)
         return term_units != 'ha' or value <= 1 or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].value",
@@ -145,3 +148,58 @@ def validate_product_ha_functional_unit_ha(cycle: dict, list_key: str = 'product
 
     return functional_unit != CycleFunctionalUnit._1_HA.value or \
         _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
+
+
+DEFAULT_THRESHOLD = 0.95
+DEFAULT_ZSCORE = 1.96
+CI_TO_ZSCORE = {
+    0.9: 1.65,
+    DEFAULT_THRESHOLD: DEFAULT_ZSCORE,
+    0.99: 2.58
+}
+
+
+def _get_mu_sd(country_id: str, product_id: str):
+    mu, sd = get_post(country_id, product_id)
+    return (mu, sd) if mu is not None else get_prior(country_id, product_id)
+
+
+def _validate_yield(country_id: str, product_id: str, yields: list[float], threshold: float = DEFAULT_THRESHOLD):
+    z = CI_TO_ZSCORE[threshold]
+    mu, sd = _get_mu_sd(country_id, product_id)
+    min = mu-(z*sd) if mu is not None else None
+    max = mu+(z*sd) if mu is not None else None
+    passes = [min <= y <= max if mu is not None else True for y in yields]
+    outliers = np.array(yields)[~np.array(passes)]
+    return all(passes), outliers, min, max
+
+
+def validate_product_yield(cycle: dict, site: dict, list_key: str = 'products', threshold: float = DEFAULT_THRESHOLD):
+    country_id = site.get('country', {}).get('@id')
+
+    def validate(values: tuple):
+        index, product = values
+
+        product_id = product.get('term', {}).get('@id')
+        product_value = product.get('value', [])
+
+        valid, outliers, min, max = _validate_yield(country_id, product_id, product_value, threshold)
+        return valid or {
+            'level': 'warning',
+            'dataPath': f".{list_key}[{index}].value",
+            'message': 'is outside confidence interval',
+            'params': {
+                'term': product.get('term', {}),
+                'country': site.get('country', {}),
+                'outliers': outliers,
+                'threshold': threshold,
+                'min': min,
+                'max': max
+            }
+        }
+
+    try:
+        return _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
+    except Exception as e:
+        logger.error(f"Error validating using distribution: '{str(e)}'")
+        return True
