@@ -32,10 +32,11 @@ def validate_properties_same_length(node: dict, list_key: str, prop_key: str, pr
 
 
 def validate_date_lt_today(node: dict, key: str):
-    return node.get(key) is None or _is_before_today(node.get(key)) or {
+    date = _get_dict_key(node, key)
+    return date is None or _is_before_today(date) or {
         'level': 'error',
         'dataPath': f".{key}",
-        'message': "must be lower than today's date"
+        'message': 'must be before today'
     }
 
 
@@ -502,7 +503,7 @@ def validate_list_model(node: dict, list_key: str) -> list:
     list
         List of errors from the models or `True` if no errors.
     """
-    run = os.environ.get('VALIDATE_MODELS', 'true') == 'true'
+    run = os.getenv('VALIDATE_MODELS', 'true') == 'true'
     nodes = node.get(list_key, [])
     with ThreadPoolExecutor() as executor:
         errors = list(executor.map(_validate_list_model(node, list_key), enumerate(nodes))) if run else []
@@ -568,7 +569,7 @@ def validate_list_model_config(node: dict, list_key: str, conf: dict):
     list
         List of errors from the models or `True` if no errors.
     """
-    run = os.environ.get('VALIDATE_MODELS', 'true') == 'true'
+    run = os.getenv('VALIDATE_MODELS', 'true') == 'true'
     nodes = node.get(list_key, [])
     with ThreadPoolExecutor() as executor:
         errors = list(executor.map(_validate_list_model_config(node, list_key,  conf), enumerate(nodes))) if run else []
