@@ -121,6 +121,11 @@ def test_validate_soilTexture_valid():
         data = json.load(f)
     assert validate_soilTexture(data.get('nodes')) is True
 
+    # missing value on texture
+    with open(f"{fixtures_path}/measurement/soilTexture/missing-texture-value.json") as f:
+        data = json.load(f)
+    assert validate_soilTexture(data.get('nodes')) is True
+
     # valid percent
     with open(f"{fixtures_path}/measurement/soilTexture/percent-valid.json") as f:
         data = json.load(f)
