@@ -1,12 +1,16 @@
+from unittest.mock import patch
 import json
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.product import (
     validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta, validate_primary,
-    validate_product_ha_functional_unit_ha
+    validate_product_ha_functional_unit_ha, validate_product_yield
 )
 
 
+class_path = 'hestia_earth.validation.validators.product'
+
+
 def test_validate_economicValueShare_valid():
     # no products should be valid
     assert validate_economicValueShare([]) is True
@@ -196,3 +200,86 @@ def test_validate_product_ha_functional_unit_ha_error():
             }
         }
     }
+
+
+MU = 8000
+SD = 1000
+
+
+@patch(f"{class_path}.get_post", return_value=(MU, SD))
+def test_validate_product_yield_valid_with_posterior(*args):
+    # no products should be valid
+    assert validate_product_yield({'products': []}, {}, 'products') is True
+
+    with open(f"{fixtures_path}/product/yield/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) is True
+
+
+@patch(f"{class_path}.get_post", return_value=(MU, SD))
+def test_validate_product_yield_invalid_with_posterior(*args):
+    with open(f"{fixtures_path}/product/yield/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) == {
+        'level': 'warning',
+        'dataPath': '.products[0].value',
+        'message': 'is outside confidence interval',
+        'params': {
+            'term': {
+                '@type': 'Term',
+                'termType': 'crop',
+                '@id': 'wheatGrain'
+            },
+            'country': {
+                '@type': 'Term',
+                '@id': 'GADM-GBR'
+            },
+            'outliers': [1000],
+            'threshold': 0.95,
+            'min': 6040,
+            'max': 9960
+        }
+    }
+
+
+@patch(f"{class_path}.get_prior", return_value=(MU, SD))
+@patch(f"{class_path}.get_post", return_value=(None, None))
+def test_validate_product_yield_valid_with_prior_no_posterior(*args):
+    with open(f"{fixtures_path}/product/yield/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) is True
+
+
+@patch(f"{class_path}.get_prior", return_value=(MU, SD))
+@patch(f"{class_path}.get_post", return_value=(None, None))
+def test_validate_product_yield_invalid_with_prior_no_posterior(*args):
+    with open(f"{fixtures_path}/product/yield/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) == {
+        'level': 'warning',
+        'dataPath': '.products[0].value',
+        'message': 'is outside confidence interval',
+        'params': {
+            'term': {
+                '@type': 'Term',
+                'termType': 'crop',
+                '@id': 'wheatGrain'
+            },
+            'country': {
+                '@type': 'Term',
+                '@id': 'GADM-GBR'
+            },
+            'outliers': [1000],
+            'threshold': 0.95,
+            'min': 6040,
+            'max': 9960
+        }
+    }
+
+
+@patch(f"{class_path}.get_prior", return_value=(None, None))
+@patch(f"{class_path}.get_post", return_value=(None, None))
+def test_validate_product_yield_valid_no_prior_no_posterior(*args):
+    with open(f"{fixtures_path}/product/yield/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) is True
