@@ -548,6 +548,7 @@ def test_validate_date_lt_today_valid():
     key = 'date'
     assert validate_date_lt_today({key: '2000-01-01'}, key) is True
     assert validate_date_lt_today({key: '2022'}, key) is True
+    assert validate_date_lt_today({'test': {key: '2022'}}, f"test.{key}") is True
 
 
 def test_validate_date_lt_today_invalid():
@@ -556,7 +557,7 @@ def test_validate_date_lt_today_invalid():
     assert validate_date_lt_today(node, key) == {
         'level': 'error',
         'dataPath': '.date',
-        'message': "must be lower than today's date"
+        'message': 'must be before today'
     }
 
 
@@ -590,7 +591,7 @@ def test_validate_list_date_lt_today_invalid():
     assert validate_list_date_lt_today(node, 'list', keys) == {
         'level': 'error',
         'dataPath': '.list[1].date2',
-        'message': "must be lower than today's date"
+        'message': 'must be before today'
     }
 
 
